==> patch-2.3.5.0.zip: app/views/report/statistics/statistics.php <==
<?php
use \Core\View;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Prashanth Kumar B - prashanth.kumar@parablu.com
* @version 2.0
* @date 7/10/15
* @time 11:55 AM
*
*/

?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><a href="<?=Url::basePath('report/dashboard')?>"><?=$data['title']?></a></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="ReportController">
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php View::renderTemplate('partials/sideBar', $data); ?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11 ng-cloak">
            <span class="csrf_token hide"><?=$data['csrf_token']?></span>
            <span class="currentPage hide"><?='statistics'?></span>
            <div class="row">
                <div class="panel">
                    <div class="panel-heading"><h3>Backup Statistics</h3></div>
                    <div class="panel-body">
                        <ul class="list-group">
                            <li class="list-group-item">
                                <span>Active Users</span>
                                <span class="pull-right" ng-cloak>{{ statistics.usersConnected }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Active Devices</span>
                                <span class="pull-right" ng-cloak>{{ statistics.devicesConnected }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Average number of Backups Per Device</span>
                                <span class="pull-right" ng-cloak>{{ statistics.avgNumberofBackups }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Total size of Data Backed up</span>
                                <span class="pull-right" ng-cloak>{{ statistics.totalStorageUtilized }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Average Storage Utilized per user</span>
                                <span class="pull-right" ng-cloak>{{ statistics.avgStoragePerUser }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Completed Restores</span>
                                <span class="pull-right" ng-cloak>{{ statistics.restoresDone }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Average Restore per user</span>
                                <span class="pull-right" ng-cloak>{{ statistics.avgRestorePerUser }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Completed Backups</span>
                                <span class="pull-right" ng-cloak>{{ statistics.backupsDone }}</span>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script>
    $('.timePicker').timepicker({
        showMeridian: false,
        defaultTime: '9:45'
    });
</script>
<script src="<?=Url::templatePath()?>js/angular/controllers/ReportController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>

==> patch-2.5.3.18_3.zip: app/views/report/statistics/statistics.php <==
<?php
use \Core\View;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Prashanth Kumar B - prashanth.kumar@parablu.com
* @version 2.0
* @date 7/10/15
* @time 11:55 AM
*
*/

?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><a href="<?=Url::basePath('report/dashboard')?>"><?=$data['title']?></a></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="ReportController">
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php if(!isMobile()){ View::renderTemplate('partials/sideBar', $data); }?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11 ng-cloak">
            <span class="csrf_token hide"><?=$data['csrf_token']?></span>
            <span class="currentPage hide"><?='statistics'?></span>
            <div class="row">
                <div class="panel">
                    <div class="panel-heading"><h3>Backup Statistics</h3></div>
                    <div class="panel-body">
                        <ul class="list-group">
                            <li class="list-group-item">
                                <span>Active Users</span>
                                <span class="pull-right" ng-cloak>{{ statistics.usersConnected }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Active Devices</span>
                                <span class="pull-right" ng-cloak>{{ statistics.devicesConnected }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Average number of Backups Per Device</span>
                                <span class="pull-right" ng-cloak>{{ statistics.avgNumberofBackups }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Total size of Data Backed up</span>
                                <span class="pull-right" ng-cloak>{{ statistics.totalStorageUtilized }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Average Storage Utilized per user</span>
                                <span class="pull-right" ng-cloak>{{ statistics.avgStoragePerUser }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Completed Restores</span>
                                <span class="pull-right" ng-cloak>{{ statistics.restoresDone }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Average Restore per user</span>
                                <span class="pull-right" ng-cloak>{{ statistics.avgRestorePerUser }}</span>
                            </li>
                            <li class="list-group-item">
                                <span>Completed Backups</span>
                                <span class="pull-right" ng-cloak>{{ statistics.backupsDone }}</span>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script>
    $('.timePicker').timepicker({
        showMeridian: false,
        defaultTime: '9:45'
    });
</script>
<script src="<?=Url::templatePath()?>js/angular/controllers/ReportController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>
